var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));

// src/editor/index.tsx
import React, {
  useEffect,
  useRef,
  forwardRef,
  useImperativeHandle,
  useState,
  useMemo,
  useCallback
} from "react";
import { EditorState, EditorSelection, StateEffect } from "@codemirror/state";
import { EditorView, placeholder } from "@codemirror/view";
import { javascript } from "@codemirror/lang-javascript";
import { xcodeLight } from "@uiw/codemirror-theme-xcode";
import { autocompletion } from "@codemirror/autocomplete";
import { basicSetup } from "@uiw/codemirror-extensions-basic-setup";
import {
  CompletionDisplay,
  completionSource,
  EventExt,
  UpdateListener,
  defineTheme
} from "./extension";
import styles from "./index.module.less";
var DefaultBasicOptions = {
  lineNumbers: false,
  foldGutter: false,
  highlightActiveLine: false,
  bracketMatching: true,
  closeBrackets: true,
  closeBracketsKeymap: true,
  tabSize: 2,
  autocompletion: true,
  searchKeymap: false,
  syntaxHighlighting: true
};
var CodeEditor = ({
  value,
  theme,
  completions = [],
  placeholder: placeholderStr = "请输入表达式",
  events,
  options = DefaultBasicOptions,
  className,
  onChange
}, ref) => {
  const containerRef = useRef();
  const [view, setView] = useState();
  useImperativeHandle(
    ref,
    () => __spreadProps(__spreadValues({}, view), {
      getDoc() {
        return view.state.doc.toString();
      },
      insertDoc
    }),
    [view]
  );
  const customTheme = useMemo(() => defineTheme(theme), [theme]);
  const placeHolder = useMemo(
    () => placeholder(placeholderStr),
    [placeholderStr]
  );
  const autocompletionExtension = useMemo(
    () => autocompletion({
      activateOnTyping: false,
      override: [completionSource(completions)]
    }),
    [completions]
  );
  const readOnly = useMemo(
    () => EditorState.readOnly.of(!!(options == null ? void 0 : options.readonly)),
    [options == null ? void 0 : options.readonly]
  );
  const insertDoc = useCallback(
    (text) => {
      const { anchor, head } = view.state.selection.ranges[0];
      view.dispatch({
        changes: { from: head, insert: text || "" },
        selection: EditorSelection.range(anchor, head)
      });
    },
    [view]
  );
  useEffect(() => {
    const state = EditorState.create({
      doc: value,
      extensions: [
        basicSetup(__spreadValues(__spreadValues({}, DefaultBasicOptions), options)),
        readOnly,
        customTheme,
        placeHolder,
        EventExt(events),
        xcodeLight,
        javascript(),
        autocompletionExtension,
        CompletionDisplay(),
        UpdateListener(onChange),
        EditorView.lineWrapping
      ]
    });
    const view2 = new EditorView({
      parent: containerRef.current,
      state
    });
    setView(view2);
    return () => {
      view2.destroy();
    };
  }, [readOnly]);
  useEffect(() => {
    if (value === void 0) {
      return;
    }
    const currentValue = view ? view.state.doc.toString() : "";
    if (view && value !== currentValue) {
      insertDoc(value);
    }
  }, [value, view]);
  useEffect(() => {
    if (view) {
      view.state.update({
        effects: StateEffect.reconfigure.of([autocompletionExtension])
      });
    }
  }, [autocompletionExtension]);
  return /* @__PURE__ */ React.createElement(
    "div",
    {
      className: `${styles.container} ${className != null ? className : ""}`,
      ref: containerRef
    }
  );
};
var editor_default = forwardRef(CodeEditor);
export {
  editor_default as default
};
